package sistema;

import java.io.InputStream;
import java.nio.file.Paths;
import java.util.Calendar;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.Part;

public final class ArquivoUpload {
    private String nome;
    private String nomeFisico;
    private String extensao;
    private String tipo;
    private long tamanho;
    private final InputStream inputStream;
    
    public ArquivoUpload(HttpServletRequest request, String campo) throws Exception {
        this(request, campo, false);
    }
    
    public ArquivoUpload(HttpServletRequest request, String campo, boolean nomeFisicoReal) throws Exception {
        Part parteArquivo = request.getPart(campo);
        setNome(Paths.get(parteArquivo.getSubmittedFileName()).getFileName().toString());
        if ( !nomeFisicoReal ) {
            setNomeFisico( String.valueOf(Calendar.getInstance().getTimeInMillis()));
        }
        this.tipo = parteArquivo.getContentType();
        this.tamanho = parteArquivo.getSize();
        inputStream = parteArquivo.getInputStream();
    }

    public String getNome() {
        return nome;
    }

    private void setNome(String nome) {
        this.nome = nome;
        this.nomeFisico = nome;
        this.extensao = Util.getExtensao(nome);
    }

    public String getNomeFisico() {
        return nomeFisico;
    }

    private void setNomeFisico(String nomeFisico) {
        String extensaoFisico = Util.getExtensao(nomeFisico);
        this.nomeFisico = nomeFisico;
        if ( extensao != null && !extensao.equals(extensaoFisico) ) {
            this.nomeFisico = Util.trocarExtensao(nomeFisico, extensao);
        }
    }

    public String getExtensao() {
        return extensao;
    }

    public String getTipo() {
        return tipo;
    }

    private void setTipo(String tipo) {
        this.tipo = tipo;
    }
    
    public InputStream getInputStream() {
        return inputStream;
    }

    public long getTamanho() {
        return tamanho;
    }

    public void setTamanho(long tamanho) {
        this.tamanho = tamanho;
    }
    
    @Override
    public String toString() {
        return "Arquivo{" + 
                "\n nome=" + nome + 
                "\n nomeFisico=" + nomeFisico + 
                "\n extensao=" + extensao + 
                "\n tipo=" + tipo + 
                "\n tamanho=" + tamanho + 
                '}';
    }
    
    
}
